==> zio-aws-ssoadmin_2.13-5.19.7.1-sources.jar: zio/aws/ssoadmin/model/InstanceMetadata.scala <==
package zio.aws.ssoadmin.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.ssoadmin.model.primitives.{Id, InstanceArn}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class InstanceMetadata(
    instanceArn: Optional[InstanceArn] = Optional.Absent,
    identityStoreId: Optional[Id] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ssoadmin.model.InstanceMetadata = {
    import InstanceMetadata.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ssoadmin.model.InstanceMetadata
      .builder()
      .optionallyWith(
        instanceArn.map(value => InstanceArn.unwrap(value): java.lang.String)
      )(_.instanceArn)
      .optionallyWith(
        identityStoreId.map(value => Id.unwrap(value): java.lang.String)
      )(_.identityStoreId)
      .build()
  }
  def asReadOnly: zio.aws.ssoadmin.model.InstanceMetadata.ReadOnly =
    zio.aws.ssoadmin.model.InstanceMetadata.wrap(buildAwsValue())
}
object InstanceMetadata {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ssoadmin.model.InstanceMetadata
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ssoadmin.model.InstanceMetadata =
      zio.aws.ssoadmin.model.InstanceMetadata(
        instanceArn.map(value => value),
        identityStoreId.map(value => value)
      )
    def instanceArn: Optional[InstanceArn]
    def identityStoreId: Optional[Id]
    def getInstanceArn: ZIO[Any, AwsError, InstanceArn] =
      AwsError.unwrapOptionField("instanceArn", instanceArn)
    def getIdentityStoreId: ZIO[Any, AwsError, Id] =
      AwsError.unwrapOptionField("identityStoreId", identityStoreId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ssoadmin.model.InstanceMetadata
  ) extends zio.aws.ssoadmin.model.InstanceMetadata.ReadOnly {
    override val instanceArn: Optional[InstanceArn] = zio.aws.core.internal
      .optionalFromNullable(impl.instanceArn())
      .map(value => zio.aws.ssoadmin.model.primitives.InstanceArn(value))
    override val identityStoreId: Optional[Id] = zio.aws.core.internal
      .optionalFromNullable(impl.identityStoreId())
      .map(value => zio.aws.ssoadmin.model.primitives.Id(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.ssoadmin.model.InstanceMetadata
  ): zio.aws.ssoadmin.model.InstanceMetadata.ReadOnly = new Wrapper(impl)
}

==> zio-aws-ssoadmin_3-5.17.158.1-sources.jar: zio/aws/ssoadmin/model/InstanceMetadata.scala <==
package zio.aws.ssoadmin.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.ssoadmin.model.primitives.{Id, InstanceArn}
import scala.jdk.CollectionConverters.*
final case class InstanceMetadata(
    instanceArn: Option[InstanceArn] = None,
    identityStoreId: Option[Id] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ssoadmin.model.InstanceMetadata = {
    import InstanceMetadata.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ssoadmin.model.InstanceMetadata
      .builder()
      .optionallyWith(
        instanceArn.map(value => InstanceArn.unwrap(value): java.lang.String)
      )(_.instanceArn)
      .optionallyWith(
        identityStoreId.map(value => Id.unwrap(value): java.lang.String)
      )(_.identityStoreId)
      .build()
  }
  def asReadOnly: zio.aws.ssoadmin.model.InstanceMetadata.ReadOnly =
    zio.aws.ssoadmin.model.InstanceMetadata.wrap(buildAwsValue())
}
object InstanceMetadata {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ssoadmin.model.InstanceMetadata
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ssoadmin.model.InstanceMetadata =
      zio.aws.ssoadmin.model.InstanceMetadata(
        instanceArn.map(value => value),
        identityStoreId.map(value => value)
      )
    def instanceArn: Option[InstanceArn]
    def identityStoreId: Option[Id]
    def getInstanceArn: ZIO[Any, AwsError, InstanceArn] =
      AwsError.unwrapOptionField("instanceArn", instanceArn)
    def getIdentityStoreId: ZIO[Any, AwsError, Id] =
      AwsError.unwrapOptionField("identityStoreId", identityStoreId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ssoadmin.model.InstanceMetadata
  ) extends zio.aws.ssoadmin.model.InstanceMetadata.ReadOnly {
    override val instanceArn: Option[InstanceArn] = scala
      .Option(impl.instanceArn())
      .map(value => zio.aws.ssoadmin.model.primitives.InstanceArn(value))
    override val identityStoreId: Option[Id] = scala
      .Option(impl.identityStoreId())
      .map(value => zio.aws.ssoadmin.model.primitives.Id(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.ssoadmin.model.InstanceMetadata
  ): zio.aws.ssoadmin.model.InstanceMetadata.ReadOnly = new Wrapper(impl)
}
